import { HttpError } from '../errors/HttpError';
import type { AsyncHandler } from './AsyncHandler';
/**
 * Combines a list of errors into a single HttpErrors.
 * Status code depends on the input errors. If they all share the same status code that code will be re-used.
 * If they are all within the 4xx range, 400 will be used, otherwise 500.
 *
 * @param errors - Errors to combine.
 * @param messagePrefix - Prefix for the aggregate error message. Will be followed with an array of all the messages.
 */
export declare function createAggregateError(errors: Error[], messagePrefix?: string): HttpError;
/**
 * Finds a handler that can handle the given input data.
 * Otherwise an error gets thrown.
 *
 * @param handlers - List of handlers to search in.
 * @param input - The input data.
 *
 * @returns A promise resolving to a handler that supports the data or otherwise rejecting.
 */
export declare function findHandler<TIn, TOut>(handlers: AsyncHandler<TIn, TOut>[], input: TIn): Promise<AsyncHandler<TIn, TOut>>;
/**
 * Filters a list of handlers to only keep those that can handle the input.
 * Will error if no matching handlers are found.
 *
 * @param handlers - Handlers to filter.
 * @param input - Input that needs to be supported.
 */
export declare function filterHandlers<TIn, TOut>(handlers: AsyncHandler<TIn, TOut>[], input: TIn): Promise<AsyncHandler<TIn, TOut>[]>;
