"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KEY_CONTEXT_HTTPPROXYHANDLER = exports.ActorHttpProxy = void 0;
const bus_http_1 = require("@comunica/bus-http");
const context_entries_1 = require("@comunica/context-entries");
/**
 * A comunica Proxy Http Actor.
 */
class ActorHttpProxy extends bus_http_1.ActorHttp {
    constructor(args) {
        super(args);
    }
    async test(action) {
        if (!action.context) {
            throw new Error(`Actor ${this.name} could not find a context.`);
        }
        const proxyHandler = action.context.get(context_entries_1.KeysHttpProxy.httpProxyHandler);
        if (!proxyHandler) {
            throw new Error(`Actor ${this.name} could not find a proxy handler in the context.`);
        }
        if (!await proxyHandler.getProxy(action)) {
            throw new Error(`Actor ${this.name} could not determine a proxy for the given request.`);
        }
        return { time: Number.POSITIVE_INFINITY };
    }
    async run(action) {
        const requestedUrl = typeof action.input === 'string' ? action.input : action.input.url;
        if (!action.context) {
            throw new Error('Illegal state: missing context');
        }
        const proxyHandler = action.context.get(context_entries_1.KeysHttpProxy.httpProxyHandler);
        // Send a request for the modified request
        const output = await this.mediatorHttp.mediate(Object.assign(Object.assign({}, await proxyHandler.getProxy(action)), { context: action.context.delete(context_entries_1.KeysHttpProxy.httpProxyHandler) }));
        // Modify the response URL
        // use defineProperty to allow modification of unmodifiable objects
        Object.defineProperty(output, 'url', {
            configurable: true,
            enumerable: true,
            get: () => { var _a; return (_a = output.headers.get('x-final-url')) !== null && _a !== void 0 ? _a : requestedUrl; },
        });
        return output;
    }
}
exports.ActorHttpProxy = ActorHttpProxy;
/**
 * @deprecated Import this constant from @comunica/context-entries.
 */
exports.KEY_CONTEXT_HTTPPROXYHANDLER = context_entries_1.KeysHttpProxy.httpProxyHandler;
//# sourceMappingURL=ActorHttpProxy.js.map