import type { IQuadDestination } from '@comunica/bus-rdf-update-quads';
import type { IAction, IActorArgs, IActorOutput, IActorTest } from '@comunica/core';
import { Actor } from '@comunica/core';
/**
 * A comunica actor for rdf-update-hypermedia events.
 *
 * Actor types:
 * * Input:  IActionRdfUpdateHypermedia:      The metadata in the document.
 * * Test:   <none>
 * * Output: IActorRdfUpdateHypermediaOutput: An RDF destination.
 *
 * @see IActionRdfUpdateHypermedia
 * @see IActorRdfUpdateHypermediaOutput
 */
export declare abstract class ActorRdfUpdateHypermedia extends Actor<IActionRdfUpdateHypermedia, IActorTest, IActorRdfUpdateHypermediaOutput> {
    protected readonly destinationType: string;
    constructor(args: IActorArgs<IActionRdfUpdateHypermedia, IActorTest, IActorRdfUpdateHypermediaOutput>, destinationType: string);
    test(action: IActionRdfUpdateHypermedia): Promise<IActorTest>;
    abstract testMetadata(action: IActionRdfUpdateHypermedia): Promise<IActorTest>;
}
export interface IActionRdfUpdateHypermedia extends IAction {
    /**
     * The URL of the destination that was fetched.
     */
    url: string;
    /**
     * A metadata key-value mapping.
     */
    metadata: Record<string, any>;
    /**
     * If the destination already exists.
     */
    exists: boolean;
    /**
     * The explicitly requested destination type.
     * If set, the destination type of the actor MUST explicitly match the given forced type.
     */
    forceDestinationType?: string;
}
export interface IActorRdfUpdateHypermediaOutput extends IActorOutput {
    /**
     * The destination for quads.
     */
    destination: IQuadDestination;
}
