import { get as get$1 } from 'http';
import { get } from 'https';
import { once } from 'events';
import { JOSEError } from '../util/errors.mjs';
import { decoder, concat } from '../lib/buffer_utils.mjs';

const protocols = {
    'https:': get,
    'http:': get$1,
};
const fetchJwks = async (url, timeout, options) => {
    if (protocols[url.protocol] === undefined) {
        throw new TypeError('Unsupported URL protocol.');
    }
    const { agent } = options;
    const req = protocols[url.protocol](url.href, {
        agent,
        timeout,
    });
    const [response] = await once(req, 'response');
    if (response.statusCode !== 200) {
        throw new JOSEError('Expected 200 OK from the JSON Web Key Set HTTP response');
    }
    const parts = [];
    for await (const part of response) {
        parts.push(part);
    }
    try {
        return JSON.parse(decoder.decode(concat(...parts)));
    }
    catch (err) {
        throw new JOSEError('Failed to parse the JSON Web Key Set HTTP response as JSON');
    }
};

export default fetchJwks;
