import * as crypto from 'crypto';
import { isCryptoKey as impl, getKeyObject } from './webcrypto.mjs';
import getSecretKey from './secret_key.mjs';

function getSignVerifyKey(alg, key, usage) {
    if (key instanceof crypto.KeyObject) {
        return key;
    }
    if (key instanceof Uint8Array) {
        if (!alg.startsWith('HS')) {
            throw new TypeError('symmetric keys are only applicable for HMAC-based JWA algorithms');
        }
        return getSecretKey(key);
    }
    if (impl(key)) {
        return getKeyObject(key, alg, new Set([usage]));
    }
    throw new TypeError('invalid key input');
}

export default getSignVerifyKey;
