import * as crypto from 'crypto';
import { promisify } from 'util';
import dsaDigest from './dsa_digest.mjs';
import keyForCrypto from './node_key.mjs';
import sign from './sign.mjs';
import getSignVerifyKey from './get_sign_verify_key.mjs';

const [major, minor] = process.version
    .substr(1)
    .split('.')
    .map((str) => parseInt(str, 10));
const oneShotCallbackSupported = major >= 16 || (major === 15 && minor >= 13);
let oneShotVerify;
if (crypto.verify.length > 4 && oneShotCallbackSupported) {
    oneShotVerify = promisify(crypto.verify);
}
else {
    oneShotVerify = crypto.verify;
}
const verify = async (alg, key, signature, data) => {
    if (alg.startsWith('HS')) {
        const expected = await sign(alg, getSignVerifyKey(alg, key, 'verify'), data);
        const actual = signature;
        try {
            return crypto.timingSafeEqual(actual, expected);
        }
        catch {
            return false;
        }
    }
    const algorithm = dsaDigest(alg);
    const keyObject = getSignVerifyKey(alg, key, 'verify');
    const keyInput = keyForCrypto(alg, keyObject);
    try {
        return await oneShotVerify(algorithm, data, keyInput, signature);
    }
    catch {
        return false;
    }
};

export default verify;
