/// <reference types="node" />
import { EventEmitter } from "events";
import { ILoginInputOptions, InMemoryStorage, ISessionInfo, IStorage } from "@inrupt/solid-client-authn-core";
import ClientAuthentication from "./ClientAuthentication";
export interface ISessionOptions {
    secureStorage: IStorage;
    insecureStorage: IStorage;
    storage: IStorage;
    sessionInfo: ISessionInfo;
    clientAuthentication: ClientAuthentication;
    onNewRefreshToken?: (newToken: string) => unknown;
}
export declare const defaultStorage: InMemoryStorage;
export declare class Session extends EventEmitter {
    readonly info: ISessionInfo;
    private clientAuthentication;
    private tokenRequestInProgress;
    private onNewRefreshToken?;
    constructor(sessionOptions?: Partial<ISessionOptions>, sessionId?: string);
    login: (options: ILoginInputOptions) => Promise<void>;
    fetch: (url: RequestInfo, init?: RequestInit | undefined) => Promise<Response>;
    logout: () => Promise<void>;
    handleIncomingRedirect: (url: string) => Promise<ISessionInfo | undefined>;
    onLogin(callback: () => unknown): void;
    onLogout(callback: () => unknown): void;
}
