"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeBase64UrlEncodedJson = void 0;
const base64url_1 = require("jose/util/base64url");
const Base64UrlEncodedJsonDecodingError_1 = require("../error/Base64UrlEncodedJsonDecodingError");
/**
 * Decodes base 64 URL encoded JSON objects
 *
 * See also: https://datatracker.ietf.org/doc/html/rfc7519#section-7.2
 *
 * @param encodedJson The base64 URL encoded JSON
 * @returns The access token as a JSON
 */
function decodeBase64UrlEncodedJson(encodedJson) {
    try {
        return JSON.parse(new TextDecoder().decode((0, base64url_1.decode)(encodedJson)));
    }
    catch {
        throw new Base64UrlEncodedJsonDecodingError_1.Base64UrlEncodedJsonDecodingError(encodedJson);
    }
}
exports.decodeBase64UrlEncodedJson = decodeBase64UrlEncodedJson;
//# sourceMappingURL=decodeBase64UrlEncodedJson.js.map