"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrieveAccessTokenIssuerKeySet = void 0;
const cross_fetch_1 = require("cross-fetch");
const remote_1 = __importDefault(require("jose/jwks/remote"));
const primitive_type_1 = require("ts-guards/dist/primitive-type");
const standard_object_1 = require("ts-guards/dist/standard-object");
const error_1 = require("../error");
function wellKnownOpenidConfigUrl(iss) {
    return iss.replace(/\/$/, "").concat("/.well-known/openid-configuration");
}
async function dereferenceIssuerConfiguration(iss) {
    const configUrl = wellKnownOpenidConfigUrl(iss);
    /* eslint-disable @typescript-eslint/naming-convention */
    const response = await (0, cross_fetch_1.fetch)(configUrl, {
        method: "GET",
        headers: { "Content-Type": "application/json" },
    });
    /* eslint-enable @typescript-eslint/naming-convention */
    if (response.ok) {
        return (await response.json());
    }
    throw new error_1.IssuerConfigurationDereferencingError(response.status.toString(), configUrl);
}
async function jwksUri(iss) {
    const issuerConfig = await dereferenceIssuerConfiguration(iss);
    if ((0, standard_object_1.isObjectPropertyOf)(issuerConfig, "jwks_uri") &&
        (0, primitive_type_1.isString)(issuerConfig.jwks_uri)) {
        try {
            return new URL(issuerConfig.jwks_uri);
        }
        catch (_) {
            throw new Error(`SolidIdentityIssuerConfigError Failed parsing jwks_uri from identity issuer configuration at URL ${iss.toString()} as a URL`);
        }
    }
    throw new Error(`SolidIdentityIssuerConfigError Failed extracting jwks_uri from identity issuer configuration at URL ${iss.toString()}`);
}
async function retrieveAccessTokenIssuerKeySet(iss, getKeySet) {
    if (typeof getKeySet !== "undefined" && getKeySet !== null) {
        return getKeySet(iss);
    }
    return (0, remote_1.default)(await jwksUri(iss));
}
exports.retrieveAccessTokenIssuerKeySet = retrieveAccessTokenIssuerKeySet;
//# sourceMappingURL=retrieveAccessTokenIssuerKeySet.js.map