"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrieveWebidTrustedOidcIssuers = void 0;
const n3_1 = require("n3");
const rdf_dereference_1 = __importDefault(require("rdf-dereference"));
const error_1 = require("../error");
async function dereferenceWebid(webid) {
    try {
        return (await rdf_dereference_1.default.dereference(webid)).quads;
    }
    catch (e) {
        throw new error_1.WebidDereferencingError(webid);
    }
}
async function retrieveWebidTrustedOidcIssuers(webid, getIssuers) {
    if (typeof getIssuers !== "undefined" && getIssuers !== null) {
        return getIssuers(webid);
    }
    const quadStream = await dereferenceWebid(webid);
    const store = new n3_1.Store();
    const issuer = [];
    return new Promise((resolve, reject) => {
        store
            .import(quadStream)
            .on("end", () => {
            store
                .match(n3_1.DataFactory.namedNode(webid), n3_1.DataFactory.namedNode("http://www.w3.org/ns/solid/terms#oidcIssuer"))
                .on("data", (quad) => {
                issuer.push(quad.object.value);
            })
                .on("error", reject)
                .on("end", () => resolve(issuer));
        })
            .on("error", reject);
    });
}
exports.retrieveWebidTrustedOidcIssuers = retrieveWebidTrustedOidcIssuers;
//# sourceMappingURL=retrieveWebidTrustedOidcIssuers.js.map