"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebIDIssuersCache = void 0;
const lru_cache_1 = __importDefault(require("lru-cache"));
const algorithm_1 = require("../algorithm");
const config_1 = require("../config");
class WebIDIssuersCache extends lru_cache_1.default {
    constructor() {
        super({ max: config_1.maxRequestsPerSecond, maxAge: config_1.maxAgeInMilliseconds });
    }
    async getIssuers(webid) {
        const cachedValue = this.get(webid.toString());
        if (cachedValue === undefined) {
            const issuersValue = await (0, algorithm_1.retrieveWebidTrustedOidcIssuers)(webid);
            this.set(webid.toString(), issuersValue);
            return issuersValue;
        }
        return cachedValue;
    }
}
exports.WebIDIssuersCache = WebIDIssuersCache;
//# sourceMappingURL=WebIDIssuersCache.js.map