import type { ClassDeclaration, TSInterfaceDeclaration, TypeNode } from '@typescript-eslint/types/dist/ts-estree';
import type { AST, TSESTreeOptions } from '@typescript-eslint/typescript-estree';
/**
 * A collection of classes, with exported name as key.
 */
export declare type ClassIndex<T> = Record<string, T>;
/**
 * The name and location of a class.
 */
export interface ClassReference {
    packageName: string;
    localName: string;
    fileName: string;
}
/**
 * A loaded reference.
 */
export declare type ClassReferenceLoaded = ClassLoaded | InterfaceLoaded;
/**
 * A loaded class with a full class declaration.
 */
export interface ClassLoaded extends ClassReference {
    type: 'class';
    localName: string;
    fileName: string;
    declaration: ClassDeclaration;
    ast: AST<TSESTreeOptions>;
    superClass?: ClassLoaded;
    implementsInterfaces?: ClassReferenceLoaded[];
    abstract?: boolean;
    comment?: string;
    generics: GenericTypes;
}
/**
 * A hash of generic type name to its properties.
 */
export declare type GenericTypes = Record<string, {
    type?: TypeNode;
}>;
/**
 * A loaded interface with a full interface declaration.
 */
export interface InterfaceLoaded extends ClassReference {
    type: 'interface';
    localName: string;
    fileName: string;
    declaration: TSInterfaceDeclaration;
    ast: AST<TSESTreeOptions>;
    superInterfaces?: InterfaceLoaded[];
    comment?: string;
    generics: GenericTypes;
}
