import type { ClassDeclaration, MethodDefinition } from '@typescript-eslint/types/dist/ts-estree';
import type { AST, TSESTreeOptions } from '@typescript-eslint/typescript-estree';
import type { ClassIndex, ClassLoaded, ClassReferenceLoaded } from './ClassIndex';
import type { ParameterDataField, ParameterRangeUnresolved } from './ParameterLoader';
/**
 * Loads the constructor data of classes.
 */
export declare class ConstructorLoader {
    /**
     * Create a class index containing all constructor data from the classes in the given index.
     * @param classIndex An index of loaded classes.
     */
    getConstructors(classIndex: ClassIndex<ClassReferenceLoaded>): ClassIndex<ConstructorData<ParameterRangeUnresolved>>;
    /**
     * Retrieve the constructor in the given class, or its super class.
     * Can be undefined if no explicit constructor exists in this class or any of its super classes.
     * @param classLoaded A loaded class reference.
     */
    getConstructor(classLoaded: ClassLoaded): MethodDefinition | undefined;
    /**
     * Retrieve the constructor in the given class, or undefined if it could not be found.
     * @param declaration A class declaration
     */
    getConstructorInClass(declaration: ClassDeclaration): MethodDefinition | undefined;
    /**
     * Find the first class with the given name in the given parsed typescript file.
     * An error will be thrown if no class could be found with that name.
     * @param className A class name.
     * @param ast A parsed typescript file
     * @param fileName The file name, for error reporting.
     */
    getClass(className: string, ast: AST<TSESTreeOptions>, fileName: string): ClassDeclaration;
}
/**
 * Constructor parameter information
 */
export interface ConstructorData<R> {
    parameters: ParameterDataField<R>[];
}
