"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShortcutPropertyHandler = void 0;
/**
 * A proxy handler for exposing a URI-to-? map to shortcut-to-? map
 * based on a JSON-LD context.
 */
class ShortcutPropertyHandler {
    constructor(context) {
        this.context = context;
    }
    has(target, propertyKey) {
        return this.get(target, propertyKey).length > 0;
    }
    get(target, propertyKey) {
        const iri = this.context.expandTerm(this.toTermString(propertyKey), true);
        if (!iri) {
            throw new Error(`Illegal property getting for disabled context key '${this.toTermString(propertyKey)}'`);
        }
        if (!(iri in target)) {
            target[iri] = [];
        }
        return target[iri];
    }
    set(target, propertyKey, value) {
        const iri = this.context.expandTerm(this.toTermString(propertyKey), true);
        if (!iri) {
            throw new Error(`Illegal property setting for disabled context key '${this.toTermString(propertyKey)}'`);
        }
        target[iri] = value;
        return true;
    }
    ownKeys(target) {
        return Object.keys(target)
            .map((key) => this.context.expandTerm(key, true))
            .filter(key => key && this.has(target, key));
    }
    toTermString(propertyKey) {
        return typeof propertyKey === 'string' ? propertyKey : String(propertyKey);
    }
}
exports.ShortcutPropertyHandler = ShortcutPropertyHandler;
//# sourceMappingURL=ShortcutPropertyHandler.js.map