"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SingularPropertyHandler = void 0;
/**
 * A proxy handler for exposing array-valued hashes
 * as hashes with singular values.
 * This proxy will always take the first element of array values.
 */
class SingularPropertyHandler {
    has(target, propertyKey) {
        return !!this.get(target, propertyKey);
    }
    get(target, propertyKey) {
        const value = target[propertyKey];
        return value && value.length > 0 ? value[0] : undefined;
    }
    set(target, propertyKey, value) {
        target[propertyKey] = [value];
        return true;
    }
    ownKeys(target) {
        return Object.keys(target).filter(key => this.has(target, key));
    }
    deleteProperty(target, propertyKey) {
        target[propertyKey] = [];
        return true;
    }
}
exports.SingularPropertyHandler = SingularPropertyHandler;
//# sourceMappingURL=SingularPropertyHandler.js.map