/// <reference types="node" />
import { KeysHttp } from '@comunica/context-entries';
import type { IAction, IActorArgs, IActorOutput, IActorTest } from '@comunica/core';
import { Actor } from '@comunica/core';
/**
 * A base actor for listening to HTTP events.
 *
 * Actor types:
 * * Input:  IActionHttp:      The HTTP request.
 * * Test:   IActorHttpTest:   An estimate for the response time.
 * * Output: IActorHttpOutput: The HTTP response.
 *
 * @see IActionHttp
 * @see IActorHttpTest
 * @see IActorHttpOutput
 */
export declare abstract class ActorHttp extends Actor<IActionHttp, IActorTest, IActorHttpOutput> {
    constructor(args: IActorArgs<IActionHttp, IActorTest, IActorHttpOutput>);
    /**
     * Converts WhatWG streams to Node streams if required.
     * Returns the input in case the stream already is a Node stream.
     * @param {ReadableStream} body
     * @returns {NodeJS.ReadableStream}
     */
    static toNodeReadable(body: ReadableStream | null): NodeJS.ReadableStream;
    /**
     * Converts Node streams to WhatWG streams.
     * @param {NodeJS.ReadableStream} body
     * @returns {ReadableStream}
     */
    static toWebReadableStream(body: NodeJS.ReadableStream | null): ReadableStream;
    /**
     * Convert the given headers object into a raw hash.
     * @param headers A headers object.
     */
    static headersToHash(headers: Headers): Record<string, string>;
}
/**
 * The HTTP input, which contains the HTTP request.
 */
export interface IActionHttp extends IAction {
    input: RequestInfo;
    init?: RequestInit;
}
/**
 * The HTTP output, which contains the HTTP response.
 */
export interface IActorHttpOutput extends IActorOutput, Response {
}
/**
 * @type {string} Context entry for the include credentials flags.
 * @deprecated Import this constant from @comunica/context-entries.
 */
export declare const KEY_CONTEXT_INCLUDE_CREDENTIALS = KeysHttp.includeCredentials;
/**
 * @type {string} Context entry for the authentication for a source.
 * @value {string} "username:password"-pair.
 * @deprecated Import this constant from @comunica/context-entries.
 */
export declare const KEY_CONTEXT_AUTH = KeysHttp.auth;
