/// <reference types="node" />
import { IActionRdfSerialize, IActorRdfSerializeOutput } from "@comunica/bus-rdf-serialize";
import { IActionAbstractMediaTypedHandle, IActionAbstractMediaTypedMediaTypes, IActorOutputAbstractMediaTypedHandle, IActorOutputAbstractMediaTypedMediaTypes, IActorTestAbstractMediaTypedHandle, IActorTestAbstractMediaTypedMediaTypes } from '@comunica/actor-abstract-mediatyped';
import { Actor, IActorTest, Mediator } from "@comunica/core";
import * as RDF from "rdf-js";
/**
 * An RdfSerializer can serialize to any RDF serialization, based on a given content type.
 */
export declare class RdfSerializer<Q extends RDF.BaseQuad = RDF.Quad> {
    private static readonly CONTENT_MAPPINGS;
    readonly mediatorRdfSerializeMediatypes: Mediator<Actor<IActionAbstractMediaTypedMediaTypes, IActorTestAbstractMediaTypedMediaTypes, IActorOutputAbstractMediaTypedMediaTypes>, IActionAbstractMediaTypedMediaTypes, IActorTestAbstractMediaTypedMediaTypes, IActorOutputAbstractMediaTypedMediaTypes>;
    readonly mediatorRdfSerializeHandle: Mediator<Actor<IActionAbstractMediaTypedHandle<IActionRdfSerialize>, IActorTestAbstractMediaTypedHandle<IActorTest>, IActorOutputAbstractMediaTypedHandle<IActorRdfSerializeOutput>>, IActionAbstractMediaTypedHandle<IActionRdfSerialize>, IActorTestAbstractMediaTypedHandle<IActorTest>, IActorOutputAbstractMediaTypedHandle<IActorRdfSerializeOutput>>;
    constructor(args: IRdfSerializerArgs);
    /**
     * Get an array of all available content types for this serializer.
     * @return {Promise<string[]>} A promise resolving to a string array of all content types.
     */
    getContentTypes(): Promise<string[]>;
    /**
     * Get a hash of all available content types for this serializer, mapped to a numerical priority.
     * @return {Promise<{[p: string]: number}>} A promise resolving to a hash mapping content type to a priority number.
     */
    getContentTypesPrioritized(): Promise<{
        [contenType: string]: number;
    }>;
    /**
     * Serialize the given stream.
     * @param {NodeJS.ReadableStream} stream A string stream.
     * @param {ISerializeOptions} options Serialization options.
     * @return {Stream} An RDFJS quad stream.
     */
    serialize(stream: RDF.Stream, options: SerializeOptions): NodeJS.ReadableStream;
    /**
     * Get the content type based on the extension of the given path,
     * which can be an URL or file path.
     * @param {string} path A path.
     * @return {string} A content type or the empty string.
     */
    protected getContentTypeFromExtension(path: string): string;
}
export interface IRdfSerializerArgs {
    mediatorRdfSerializeMediatypes: Mediator<Actor<IActionAbstractMediaTypedMediaTypes, IActorTestAbstractMediaTypedMediaTypes, IActorOutputAbstractMediaTypedMediaTypes>, IActionAbstractMediaTypedMediaTypes, IActorTestAbstractMediaTypedMediaTypes, IActorOutputAbstractMediaTypedMediaTypes>;
    mediatorRdfSerializeHandle: Mediator<Actor<IActionAbstractMediaTypedHandle<IActionRdfSerialize>, IActorTestAbstractMediaTypedHandle<IActorTest>, IActorOutputAbstractMediaTypedHandle<IActorRdfSerializeOutput>>, IActionAbstractMediaTypedHandle<IActionRdfSerialize>, IActorTestAbstractMediaTypedHandle<IActorTest>, IActorOutputAbstractMediaTypedHandle<IActorRdfSerializeOutput>>;
}
export declare type SerializeOptions = {
    /**
     * The content type of the needed serialization.
     */
    contentType: string;
} | {
    /**
     * The file name or URL that will be serialized to.
     */
    path: string;
};
